@@ -13,15 +13,71 @@ from tqdm import tqdm
 import math
 import functools
 import zipfile
-from typing import Any, List, Union, NoReturn, Set
+from typing import Any, List, Union, NoReturn, Set, Type, Iterator, Callable
 from aitool import split_dict, Deduplication
 
 
-def file_exist(file: str) -> bool:
+def is_file(path: str) -> bool:
+    """
+    判断是否是个文件，如果是文件夹或不存在则返回False
+    :param path:
+    :return:
+    """
+    if os.path.isfile(path):
+        return True
+    return False
+
+
+def is_dir(path: str) -> bool:
+    """
+    判断是否是个文件，如果是文件夹或不存在则返回False
+    :param path:
+    :return:
+    """
+    if os.path.isdir(path):
+        return True
+    return False
+
+
+def is_file_exist(file: str) -> bool:
+    """
+    判断文件名是否存在
+    :param file: 文件名
+    :return: bool
+    """
     return os.path.exists(file)
 
 
+def file_exist(file: str) -> bool:
+    """
+    判断文件名是否存在
+    :param file: 文件名
+    :return: bool
+    """
+    print('out of data, please use is_file_exist')
+    warnings.warn("已改名为is_file_exist", DeprecationWarning)
+    return is_file_exist(file)
+
+
+def get_file(path: str) -> List[str]:
+    """
+    遍历path下的所有文件（不包括文件夹）
+    :param path: 待遍历的路径
+    :return: 文件名
+    """
+    for root, ds, fs in os.walk(path):
+        for file in fs:
+            file_path = os.path.join(root, file)
+            yield file_path
+
+
 def make_dir(file: str, is_dir=False) -> NoReturn:
+    """
+    创建文件夹
+    :param file: 文件名
+    :param is_dir: 是否为文件
+    :return: NoReturn
+    """
     if is_dir:
         path = file
     else:
@@ -35,8 +91,23 @@ def dump_json(
         file: str,
         formatting: bool = False,
         ensure_ascii: bool = False,
+        format_postfix: bool = True,
         **kwargs,
 ) -> NoReturn:
+    """
+    写入json文件
+    :param obj: 任意对象
+    :param file: 存入文件
+    :param formatting: dump with data-interchange format
+    :param ensure_ascii: ensure ascii or not
+    :param format_postfix: rename file name with tail .json
+    :param kwargs: dict-formatted parameters
+    :return: NoReturn
+    """
+    if format_postfix:
+        if file[:-5] != '.json':
+            print('rename file name with tail .json')
+            file = file + '.json'
     make_dir(file)
     kwargs['ensure_ascii'] = ensure_ascii
     if formatting:
@@ -55,7 +126,16 @@ def load_json(file: str, **kwargs,) -> Any:
         return json.load(fr, **kwargs,)
 
 
-def dump_pickle(obj: Any, file: str, **kwargs) -> NoReturn:
+def dump_pickle(
+        obj: Any,
+        file: str,
+        format_postfix: bool = True,
+        **kwargs,
+) -> NoReturn:
+    if format_postfix:
+        if file[:-4] != '.pkl':
+            print('rename file name with tail .pkl')
+            file = file + '.pkl'
     make_dir(file)
     with open(file, 'wb') as fw:
         pickle.dump(obj, fw, **kwargs)
@@ -69,29 +149,65 @@ def load_pickle(file: str, **kwargs) -> Any:
         return pickle.load(fr, **kwargs)
 
 
-def dump_lines(data: List[Any], file: str) -> NoReturn:
+def dump_lines(
+        data: List[Any],
+        file: str,
+) -> NoReturn:
     make_dir(file)
     with open(file, 'w', encoding='utf8') as fout:
         for d in data:
             print(d, file=fout)
 
 
+class Accessor:
+    """
+    用于打开文件
+    """
+    def __init__(self, file: str, open_method: str = 'fileinput') -> NoReturn:
+        self.file = file
+        self.iterator = None
+        if open_method == 'open':
+            self.iterator = open(self.file, 'r', encoding='utf8')
+        if open_method == 'fileinput':
+            self.iterator = fileinput.input([self.file])
+
+    def __enter__(self) -> Iterator:
+        return self.iterator
+
+    def get_iterator(self) -> Iterator:
+        return self.iterator
+
+    def close(self) -> NoReturn:
+        if self.iterator:
+            self.iterator.close()
+
+    def __exit__(self, exc_type, exc_val, exc_tb) -> NoReturn:
+        self.close()
+
+
+def repeat(item: Any) -> Any:
+    """
+    原样返回输入，用于作为Callable参数的默认值
+    """
+    return item
+
+
 def load_line(
         file: str,
         separator: Union[None, str] = None,
-        separator_time: int = -1,
-        form: str = None,
+        max_split: int = -1,
         deduplication: bool = False,
-        use_open: bool = False,
-) -> Union[str, List[str], Set[str]]:
+        line_processor: Callable = repeat,
+        open_method: str = 'open',
+) -> Iterator:
     """
     按行读入文件，会去掉每行末尾的换行符
     :param file: 文件路径
     :param separator: 用separator切分每行内容，None表示不做切分
-    :param separator_time: 控制separator的切分次数，-1表示不限制次数
-    :param form: 若为'set'会用set格式输出每行的结果
+    :param max_split: 控制separator的切分次数，-1表示不限制次数
+    :param line_processor: 一个函数，对separator的结果做处理
     :param deduplication: 若为True，将不输出重复的行
-    :param use_open: 若为False，将用fileinput打开文件，而非用open
+    :param open_method: 指定打开文件的方法
     :return: 文件每行的内容
     """
     cache = Deduplication()
@@ -102,45 +218,28 @@ def load_line(
                 continue
             item = line.rstrip('\n\r')
             if separator:
-                if separator_time == -1:
-                    item = item.split(separator)
-                else:
-                    item = item.split(separator, separator_time)
-            if form == 'set':
-                item = set(item)
-            yield item
+                item = item.split(separator, max_split)
+            yield line_processor(item)
 
-    if use_open:
-        file_iterator = open(file, 'r', encoding='utf8')
-    else:
-        file_iterator = fileinput.input([file])
-    yield from inner_line_process(file_iterator)
-    file_iterator.close()
+    with Accessor(file, open_method=open_method) as file_iterator:
+        yield from inner_line_process(file_iterator)
 
 
 def load_big_data(
         file: str,
         separator: Union[None, str] = None,
-        separator_time: int = -1,
-        form: str = None,
+        max_split: int = -1,
         deduplication: bool = False,
+        line_processor: Callable = repeat,
 ) -> Union[str, List[str], Set[str]]:
-    """
-    按行读入文件，会去掉每行末尾的换行符
-    :param file: 文件路径
-    :param separator: 用separator切分每行内容，None表示不做切分
-    :param separator_time: 控制separator的切分次数，-1表示不限制次数
-    :param form: 若为'set'会用set格式输出每行的结果
-    :param deduplication: 若为True，将不输出重复的行
-    :return: 文件每行的内容
-    """
     warnings.warn("已合并到load_line，可通过use_open=False调用", DeprecationWarning)
     yield from load_line(
         file=file,
         separator=separator,
-        separator_time=separator_time,
-        form=form,
+        max_split=max_split,
+        line_processor=line_processor,
         deduplication=deduplication,
+        open_method='fileinput',
     )
 
 
@@ -182,9 +281,20 @@ def dump_panda(
         file: str,
         file_format: str,
         dump_index: bool = False,
+        format_postfix: bool = True,
         **kwargs,
 ) -> NoReturn:
+    if format_postfix:
+        if file_format == 'excel':
+            if file[:-5] != '.xlsx':
+                print('rename file name with tail .xlsx')
+                file = file + '.xlsx'
+        if file_format == 'csv':
+            if file[:-4] != '.csv':
+                print('rename file name with tail .csv')
+                file = file + '.csv'
     make_dir(file)
+
     if 'index' in kwargs and isinstance(kwargs['index'], bool):
         raise ValueError('The parameter `index` is for pd.DataFrame. '
                          'If want to set the `index` for panda.to_csv/excel please use `dump_index`')
@@ -304,5 +414,5 @@ if __name__ == '__main__':
     # test_data = [[i] for i in range(26)]
     # test_file = 'test.xlsx'
     # dump_excel(test_data, test_file)
-    for text in load_line('A.log'):
+    for text in load_big_data('A.log', separator=' '):
         print(text)
